# core/models.py
from django.db import models
from django.contrib.auth.models import User

class Client(models.Model):
    name = models.CharField(max_length=255)
    company = models.CharField(max_length=255)
    status = models.CharField(max_length=20,choices=[('Lead','Lead'),('Proposal','Proposal'),('Retention','Retention'),('Paused','Paused'),('Left','Left')])
    email = models.EmailField()
    phone = models.CharField(max_length=20)
    address = models.CharField(max_length=255,blank=True, null=True)
    additonal = models.TextField(blank=True, null=True)

    def __str__(self):
        return self.name

class Product(models.Model):
    name = models.CharField(max_length=255)
    client = models.ForeignKey(Client, on_delete=models.CASCADE)
    product_type = models.CharField(max_length=50, choices=[('Domain', 'Domain'), ('Hosting', 'Hosting'), ('Website', 'Website')])
    purchase_date = models.DateField()
    description = models.TextField(blank=True, null=True)
    renewed_date = models.DateField()
    expiry_date = models.DateField()
    status = models.CharField(max_length=20, choices=[('Active', 'Active'), ('Suspended', 'Suspended'), ('Redemption','Redemption')])

    def __str__(self):
        return self.name

class Invoice(models.Model):
    client = models.ForeignKey(Client, on_delete=models.CASCADE)
    product = models.ForeignKey(Product, on_delete=models.CASCADE)
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    status = models.CharField(max_length=20, choices=[('Paid', 'Paid'), ('Unpaid', 'Unpaid')])
    payment_mode = models.CharField(max_length=20, choices=[('Cash','Cash'),('Online UPI','Online UPI')])
    received_account = models.CharField(max_length=100,blank=True,null=True)
    due_date = models.DateField()
    paid_date = models.DateField()

class Expense(models.Model):
    title = models.CharField(max_length=255)
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    category = models.CharField(max_length=50, choices=[('Server', 'Server'), ('Hosting','Hosting'), ('Domain', 'Domain'), ('Software', 'Software'),('Others','Others')])
    expense_type = models.CharField(max_length=20, choices=[('New','New'),('Renewal', 'Renewal'),('Purchase','Purchase')])
    others = models.CharField(max_length=100,blank=True,null=True)
    date = models.DateField()
